@@ -15,7 +15,6 @@ from flashfocus.display import WMEvent, WMEventType
 from flashfocus.errors import WMError
 from flashfocus.util import match_regex
 
-
 # This connection is shared by all classes/functions in the module. It is not thread-safe to
 # maintain multiple connections to sway through the same socket.
 SWAY = i3ipc.Connection()
@@ -54,13 +53,16 @@ class Window:
     def __eq__(self, other: object) -> bool:
         if type(self) != type(other):
             raise TypeError("Arguments must be of the same type")
-        return self._container.id == other._container.id
+        return self.id == other.id
 
     def __ne__(self, other: object) -> bool:
         if type(self) != type(other):
             raise TypeError("Arguments must be of the same type")
         return self.id != other.id
 
+    def __repr__(self) -> str:
+        return f"Window(id={self.id})"
+
     def match(self, criteria: Dict) -> bool:
         """Determine whether the window matches a set of criteria.
 
@@ -93,7 +95,7 @@ class DisplayHandler(Thread):
         # This is set to True when initialization of the thread is complete and its ready to begin
         # the event loop
         self.ready = False
-        super(DisplayHandler, self).__init__()
+        super().__init__()
         self.queue = queue
 
     def run(self) -> None:
@@ -127,17 +129,17 @@ def _is_mapped_window(container: i3ipc.Con) -> bool:
     return container and container.id and container.window_rect.width != 0  # type: ignore
 
 
-def get_focused_window() -> Window:
+def get_focused_window() -> Optional[Window]:
     return Window(SWAY.get_tree().find_focused())
 
 
-def get_workspace(workspace: int) -> i3ipc.Con:
+def _get_workspace_object(workspace: int) -> i3ipc.Con:
     return next(filter(lambda ws: ws.num == workspace, SWAY.get_tree().workspaces()), None)
 
 
 def list_mapped_windows(workspace: Optional[int] = None) -> List[Window]:
     if workspace is not None:
-        containers = get_workspace(workspace)
+        containers = _get_workspace_object(workspace)
     else:
         containers = SWAY.get_tree().leaves()
 
@@ -149,6 +151,18 @@ def disconnect_display_conn() -> None:
     SWAY.main_quit()
 
 
-def get_focused_workspace() -> int:
-    workspace: int = SWAY.get_tree().find_focused().workspace().num
+def get_focused_workspace() -> Optional[int]:
+    focused_container = SWAY.get_tree().find_focused()
+    if focused_container is None:
+        return None
+    workspace = focused_container.workspace()
+    if workspace is None:
+        return None
+    workspace_number = workspace.num
+    return workspace_number
+
+
+def get_workspace(window: Window) -> Optional[int]:
+    """Get the workspace that the window is mapped to."""
+    workspace = SWAY.get_tree().find_by_id(window.id).workspace().num
     return workspace
