@@ -9,9 +9,9 @@ passes the request on to the Flasher whose criteria match the window.
 import logging
 from typing import Dict, List, Tuple
 
-from flashfocus.compat import get_focused_workspace, list_mapped_windows, Window
-from flashfocus.errors import UnexpectedMessageType
+from flashfocus.compat import Window, get_focused_workspace, get_workspace, list_mapped_windows
 from flashfocus.display import WMEvent, WMEventType
+from flashfocus.errors import UnexpectedMessageType
 from flashfocus.flasher import Flasher
 
 
@@ -41,9 +41,9 @@ class FlashRouter:
     rules
         List of rules each corresponding to a set of criteria for matching against windows. The last
         rule in the list is the default rule which matches any window.
-    current_workspace: int
+    current_workspace: int | None
         The id of the current focused workspace
-    prev_workspace: int
+    prev_workspace: int | None
         The id of the previously focused workspace
     prev_focus: int
         The id of the previously focused window. We keep track of this so that
@@ -54,10 +54,10 @@ class FlashRouter:
 
     def __init__(self, config: Dict):
         if config.get("rules") is None:
-            self.rules: List[Dict] = list()
+            self.rules: List[Dict] = []
         else:
             self.rules = config["rules"]
-        self.flashers: List[Flasher] = list()
+        self.flashers: List[Flasher] = []
         # We only need to track the user's workspace if the user config requires it
         self.track_workspaces = config["flash_lone_windows"] != "always"
         for rule_config in self.rules:
@@ -86,9 +86,11 @@ class FlashRouter:
         )
         self.flashers.append(default_flasher)
         self.prev_focus = None
+        self.prev_workspace = None
+        self.current_workspace = None
         if self.track_workspaces:
-            self.current_workspace = get_focused_workspace()
             self.prev_workspace = self.current_workspace
+            self.current_workspace = get_focused_workspace()
 
     def route_request(self, message: WMEvent) -> None:
         """Match a window against rule criteria and handle the request according to it's type."""
@@ -114,7 +116,7 @@ class FlashRouter:
 
     def _route_window_init(self, window: Window) -> None:
         """Handle a window initialization event (this happens at startup)."""
-        rule, flasher = self._match(window)
+        _, flasher = self._match(window)
         flasher.set_default_opacity(window)
 
     def _route_focus_shift(self, window: Window) -> None:
@@ -131,7 +133,7 @@ class FlashRouter:
 
     def _route_client_request(self, window: Window) -> None:
         """Handle a manual flash request from the user."""
-        rule, flasher = self._match(window)
+        _, flasher = self._match(window)
         flasher.flash(window)
 
     def _match(self, window: Window) -> Tuple[Dict, Flasher]:
@@ -153,7 +155,7 @@ class FlashRouter:
         """
         if self.track_workspaces:
             self.prev_workspace = self.current_workspace
-            self.current_workspace = get_focused_workspace()
+            self.current_workspace = get_workspace(window)
 
         if not rule.get("flash_on_focus"):
             logging.debug(f"flash_on_focus is False for window {window.id}, ignoring...")
